#!/usr/bin/env python


# see: https://github.com/googleapis/python-language

from google.cloud import language_v1
from google.cloud.language_v1.types.language_service import AnalyzeSentimentResponse


def analyze_sentiment(text: str) -> AnalyzeSentimentResponse:
    """
    Args:
        text: 分析したい文章
    Returns:
        感情分析のレスポンス
        https://cloud.google.com/natural-language/docs/reference/rest/v1/documents/analyzeSentiment#response-body
    """

    # クライアントを取得する
    client = language_v1.LanguageServiceClient()

    # ドキュメントのタイプを選択する types: PLAIN_TEXT, HTML
    type_ = language_v1.Document.Type.PLAIN_TEXT

    document = language_v1.types.Document(
        content=text,
        type_=type_,
    )

    # 文字コードを指定する : NONE, UTF8, UTF16, UTF32
    encoding_type = language_v1.EncodingType.UTF8

    return client.analyze_sentiment(
        request={'document': document, 'encoding_type': encoding_type}
    )


def input_text() -> str:
    """
    標準入力から複数行のテキストを取得します。
    入力無しでEnter keyが押された場合に終了します。
    Returns:
        入力テキスト
    """
    texts = []

    while True:
        val = input()
        if len(val) == 0:
            break
        texts.append(val)
    return '\n'.join(texts)


def main() -> None:
    text = input_text()
    response = analyze_sentiment(text)
    message = ""

    # Get overall sentiment of the input document
    message += "\n== Document ==\n\n"
    message += u"Document sentiment score: {}\n".format(
        response.document_sentiment.score)
    message += u"Document sentiment magnitude: {}\n".format(
        response.document_sentiment.magnitude)
    message += "\n== Sentences in the document ==\n\n"
    # Get sentiment for all sentences in the document
    index = 0
    for sentence in response.sentences:
        index += 1
        message += u"Sentence{} text: {}\n".format(
            index, sentence.text.content)
        message += u"Sentence{} sentiment score: {}\n".format(
            index, sentence.sentiment.score)
        message += u"Sentence{} sentiment magnitude: {}\n\n".format(
            index, sentence.sentiment.magnitude)
    print(message)


if __name__ == "__main__":
    main()
